@@ -12,8 +12,6 @@ from .mappers.python import (
     PythonException,
 )
 
-# pylint: disable=attribute-defined-outside-init,no-self-use,unused-argument
-
 
 class AutoapiDocumenter(autodoc.Documenter):
     def get_attr(self, obj, name, *defargs):
@@ -79,10 +77,10 @@ class AutoapiDocumenter(autodoc.Documenter):
         elif not self.options.inherited_members:
             children = (child for child in children if not child[1].inherited)
 
-        return False, sorted(children)
+        return False, children
 
 
-class _AutoapiDocstringSignatureMixin:  # pylint: disable=too-few-public-methods
+class _AutoapiDocstringSignatureMixin:
     def format_signature(self, **kwargs):
         # Set "manual" attributes at the last possible moment.
         # This is to let a manual entry or docstring searching happen first,
@@ -93,7 +91,7 @@ class _AutoapiDocstringSignatureMixin:  # pylint: disable=too-few-public-methods
         if self.retann is None:
             self.retann = self.object.return_annotation
 
-        return super(_AutoapiDocstringSignatureMixin, self).format_signature(**kwargs)
+        return super().format_signature(**kwargs)
 
 
 class AutoapiFunctionDocumenter(
@@ -130,7 +128,7 @@ class AutoapiDecoratorDocumenter(
         if self.args is None:
             self.args = self.format_args(**kwargs)
 
-        return super(AutoapiDecoratorDocumenter, self).format_signature(**kwargs)
+        return super().format_signature(**kwargs)
 
     def format_args(self, **kwargs):
         to_format = self.object.args
@@ -170,8 +168,8 @@ class AutoapiClassDocumenter(
 
             # TODO: Change sphinx to allow overriding of getting base names
             if self.object.bases:
-                bases = [":class:`{}`".format(base) for base in self.object.bases]
-                self.add_line("   " + "Bases: {}".format(", ".join(bases)), sourcename)
+                bases = ", ".join(f":class:`{base}`" for base in self.object.bases)
+                self.add_line(f"   Bases: {bases}", sourcename)
 
 
 class AutoapiMethodDocumenter(
@@ -189,7 +187,7 @@ class AutoapiMethodDocumenter(
         return "(" + self.object.args + ")"
 
     def import_object(self):
-        result = super(AutoapiMethodDocumenter, self).import_object()
+        result = super().import_object()
 
         if result:
             self.parent = self._method_parent
@@ -213,7 +211,7 @@ class AutoapiMethodDocumenter(
             "staticmethod",
         ):
             if property_type in self.object.properties:
-                self.add_line("   :{}:".format(property_type), sourcename)
+                self.add_line(f"   :{property_type}:", sourcename)
 
 
 class AutoapiPropertyDocumenter(AutoapiDocumenter, autodoc.PropertyDocumenter):
@@ -230,14 +228,14 @@ class AutoapiPropertyDocumenter(AutoapiDocumenter, autodoc.PropertyDocumenter):
 
         sourcename = self.get_sourcename()
         if self.options.annotation and self.options.annotation is not autodoc.SUPPRESS:
-            self.add_line("   :type: %s" % self.options.annotation, sourcename)
+            self.add_line(f"   :type: {self.options.annotation}", sourcename)
 
         for property_type in (
             "abstractmethod",
             "classmethod",
         ):
             if property_type in self.object.properties:
-                self.add_line("   :{}:".format(property_type), sourcename)
+                self.add_line(f"   :{property_type}:", sourcename)
 
 
 class AutoapiDataDocumenter(AutoapiDocumenter, autodoc.DataDocumenter):
@@ -255,13 +253,11 @@ class AutoapiDataDocumenter(AutoapiDocumenter, autodoc.DataDocumenter):
         if not self.options.annotation:
             # TODO: Change sphinx to allow overriding of object description
             if self.object.value is not None:
-                self.add_line(
-                    "   :annotation: = {}".format(self.object.value), sourcename
-                )
+                self.add_line(f"   :annotation: = {self.object.value}", sourcename)
         elif self.options.annotation is autodoc.SUPPRESS:
             pass
         else:
-            self.add_line("   :annotation: %s" % self.options.annotation, sourcename)
+            self.add_line(f"   :annotation: {self.options.annotation}", sourcename)
 
 
 class AutoapiAttributeDocumenter(AutoapiDocumenter, autodoc.AttributeDocumenter):
@@ -280,13 +276,11 @@ class AutoapiAttributeDocumenter(AutoapiDocumenter, autodoc.AttributeDocumenter)
         if not self.options.annotation:
             # TODO: Change sphinx to allow overriding of object description
             if self.object.value is not None:
-                self.add_line(
-                    "   :annotation: = {}".format(self.object.value), sourcename
-                )
+                self.add_line(f"   :annotation: = {self.object.value}", sourcename)
         elif self.options.annotation is autodoc.SUPPRESS:
             pass
         else:
-            self.add_line("   :annotation: %s" % self.options.annotation, sourcename)
+            self.add_line(f"   :annotation: {self.options.annotation}", sourcename)
 
 
 class AutoapiModuleDocumenter(AutoapiDocumenter, autodoc.ModuleDocumenter):
