@@ -1,36 +1,30 @@
-# -*- coding: utf-8 -*-
-"""
-Sphinx Auto-API Top-level Extension.
+"""Sphinx Auto-API Top-level Extension.
 
 This extension allows you to automagically generate API documentation from your project.
 """
 import io
 import os
 import shutil
-import sys
+from typing import Dict, Tuple
 import warnings
 
 import sphinx
-from sphinx.util.console import darkgreen, bold
+from sphinx.util.console import colorize
 from sphinx.addnodes import toctree
 from sphinx.errors import ExtensionError
 import sphinx.util.logging
 from docutils.parsers.rst import directives
 
 from . import documenters
-from .backends import (
-    DEFAULT_FILE_PATTERNS,
-    DEFAULT_IGNORE_PATTERNS,
-    LANGUAGE_MAPPERS,
-    LANGUAGE_REQUIREMENTS,
-)
 from .directives import AutoapiSummary, NestedParse
 from .inheritance_diagrams import AutoapiInheritanceDiagram
+from .mappers import PythonSphinxMapper
 from .settings import API_ROOT
-from .toctree import add_domain_to_toctree
 
 LOGGER = sphinx.util.logging.getLogger(__name__)
 
+_DEFAULT_FILE_PATTERNS = ["*.py", "*.pyi"]
+_DEFAULT_IGNORE_PATTERNS = ["*migrations*"]
 _DEFAULT_OPTIONS = [
     "members",
     "undoc-members",
@@ -40,19 +34,16 @@ _DEFAULT_OPTIONS = [
     "special-members",
     "imported-members",
 ]
-_VIEWCODE_CACHE = {}
-"""Caches a module's parse results for use in viewcode.
-
-:type: dict(str, tuple)
-"""
+_VIEWCODE_CACHE: Dict[str, Tuple[str, Dict]] = {}
+"""Caches a module's parse results for use in viewcode."""
 
 
-class RemovedInAutoAPI2Warning(DeprecationWarning):
-    """Indicates something that will be removed in sphinx-autoapi v2."""
+class RemovedInAutoAPI3Warning(DeprecationWarning):
+    """Indicates something that will be removed in sphinx-autoapi v3."""
 
 
 if "PYTHONWARNINGS" not in os.environ:
-    warnings.filterwarnings("default", category=RemovedInAutoAPI2Warning)
+    warnings.filterwarnings("default", category=RemovedInAutoAPI3Warning)
 
 
 def _normalise_autoapi_dirs(autoapi_dirs, srcdir):
@@ -69,16 +60,8 @@ def _normalise_autoapi_dirs(autoapi_dirs, srcdir):
     return normalised_dirs
 
 
-def run_autoapi(app):  # pylint: disable=too-many-branches
-    """
-    Load AutoAPI data from the filesystem.
-    """
-    if app.config.autoapi_type not in LANGUAGE_MAPPERS:
-        allowed = ", ".join(f'"{api_type}"' for api_type in sorted(LANGUAGE_MAPPERS))
-        raise ExtensionError(
-            f"Invalid autoapi_type setting, following values are allowed: {allowed}"
-        )
-
+def run_autoapi(app):
+    """Load AutoAPI data from the filesystem."""
     if not app.config.autoapi_dirs:
         raise ExtensionError("You must configure an autoapi_dirs setting")
 
@@ -86,7 +69,7 @@ def run_autoapi(app):  # pylint: disable=too-many-branches
         warnings.warn(
             "autoapi_include_summaries has been replaced by "
             "the show-module-summary AutoAPI option\n",
-            RemovedInAutoAPI2Warning,
+            RemovedInAutoAPI3Warning,
         )
         if app.config.autoapi_include_summaries:
             app.config.autoapi_options.append("show-module-summary")
@@ -105,20 +88,6 @@ def run_autoapi(app):  # pylint: disable=too-many-branches
     )
     url_root = os.path.join("/", app.config.autoapi_root)
 
-    if not all(
-        import_name in sys.modules
-        for _, import_name in LANGUAGE_REQUIREMENTS[app.config.autoapi_type]
-    ):
-        packages = ", ".join(
-            f'{import_name} (available as "{pkg_name}" on PyPI)'
-            for pkg_name, import_name in LANGUAGE_REQUIREMENTS[app.config.autoapi_type]
-        )
-        raise ExtensionError(
-            f"AutoAPI of type `{app.config.autoapi_type}` requires following "
-            f"packages to be installed and included in extensions list: {packages}"
-        )
-
-    sphinx_mapper = LANGUAGE_MAPPERS[app.config.autoapi_type]
     template_dir = app.config.autoapi_template_dir
     if template_dir and not os.path.isabs(template_dir):
         if not os.path.isdir(template_dir):
@@ -128,19 +97,21 @@ def run_autoapi(app):  # pylint: disable=too-many-branches
                 "autoapi_template_dir will be expected to be "
                 "relative to the Sphinx source directory instead of "
                 "relative to where sphinx-build is run\n",
-                RemovedInAutoAPI2Warning,
+                RemovedInAutoAPI3Warning,
             )
-    sphinx_mapper_obj = sphinx_mapper(app, template_dir=template_dir, url_root=url_root)
+    sphinx_mapper_obj = PythonSphinxMapper(
+        app, template_dir=template_dir, url_root=url_root
+    )
 
     if app.config.autoapi_file_patterns:
         file_patterns = app.config.autoapi_file_patterns
     else:
-        file_patterns = DEFAULT_FILE_PATTERNS.get(app.config.autoapi_type, [])
+        file_patterns = _DEFAULT_FILE_PATTERNS
 
     if app.config.autoapi_ignore:
         ignore_patterns = app.config.autoapi_ignore
     else:
-        ignore_patterns = DEFAULT_IGNORE_PATTERNS.get(app.config.autoapi_type, [])
+        ignore_patterns = _DEFAULT_IGNORE_PATTERNS
 
     if ".rst" in app.config.source_suffix:
         out_suffix = ".rst"
@@ -165,27 +136,21 @@ def build_finished(app, exception):
             os.path.join(app.srcdir, app.config.autoapi_root)
         )
         if app.verbosity > 1:
-            LOGGER.info(bold("[AutoAPI] ") + darkgreen("Cleaning generated .rst files"))
+            LOGGER.info(
+                colorize("bold", "[AutoAPI] ")
+                + colorize("darkgreen", "Cleaning generated .rst files")
+            )
         shutil.rmtree(normalized_root)
 
-        sphinx_mapper = LANGUAGE_MAPPERS[app.config.autoapi_type]
-        if hasattr(sphinx_mapper, "build_finished"):
-            sphinx_mapper.build_finished(app, exception)
 
-
-def source_read(app, docname, source):  # pylint: disable=unused-argument
+def source_read(app, docname, source):
     # temp_data is cleared after each source file has been processed,
     # so populate the annotations at the beginning of every file read.
     app.env.temp_data["annotations"] = getattr(app.env, "autoapi_annotations", {})
 
 
 def doctree_read(app, doctree):
-    """
-    Inject AutoAPI into the TOC Tree dynamically.
-    """
-
-    if app.config.autoapi_add_objects_to_toctree:
-        add_domain_to_toctree(app, doctree, app.env.docname)
+    """Inject AutoAPI into the TOC Tree dynamically."""
 
     if app.env.docname == "index":
         all_docs = set()
@@ -209,10 +174,12 @@ def doctree_read(app, doctree):
                 insert = False
         if insert and app.config.autoapi_add_toctree_entry:
             # Insert AutoAPI index
-            nodes[-1]["entries"].append((None, f"{app.config.autoapi_root}/index"))
-            nodes[-1]["includefiles"].append(f"{app.config.autoapi_root}/index")
-            message_prefix = bold("[AutoAPI] ")
-            message = darkgreen(f"Adding AutoAPI TOCTree [{toc_entry}] to index.rst")
+            nodes[-1]["entries"].append((None, toc_entry))
+            nodes[-1]["includefiles"].append(toc_entry)
+            message_prefix = colorize("bold", "[AutoAPI] ")
+            message = colorize(
+                "darkgreen", f"Adding AutoAPI TOCTree [{toc_entry}] to index.rst"
+            )
             LOGGER.info(message_prefix + message)
 
 
@@ -264,7 +231,13 @@ def viewcode_follow_imported(app, modname, attribute):
     if fullname not in all_objects:
         return None
 
-    orig_path = all_objects[fullname].obj.get("original_path", "")
+    if all_objects[fullname].obj.get("type") == "method":
+        fullname = fullname[: fullname.rfind(".")]
+        attribute = attribute[: attribute.rfind(".")]
+    while all_objects[fullname].obj.get("original_path", "") != "":
+        fullname = all_objects[fullname].obj.get("original_path")
+
+    orig_path = fullname
     if orig_path.endswith(attribute):
         return orig_path[: -len(attribute) - 1]
 
@@ -274,13 +247,15 @@ def viewcode_follow_imported(app, modname, attribute):
 def setup(app):
     app.connect("builder-inited", run_autoapi)
     app.connect("source-read", source_read)
-    app.connect("doctree-read", doctree_read)
+    # Use a lower priority than the default to ensure that we can
+    # inject into the toctree before Sphinx tries to use it
+    # in another doctree-read transformer.
+    app.connect("doctree-read", doctree_read, priority=400)
     app.connect("build-finished", build_finished)
     if "viewcode-find-source" in app.events.events:
         app.connect("viewcode-find-source", viewcode_find)
     if "viewcode-follow-imported" in app.events.events:
         app.connect("viewcode-follow-imported", viewcode_follow_imported)
-    app.add_config_value("autoapi_type", "python", "html")
     app.add_config_value("autoapi_root", API_ROOT, "html")
     app.add_config_value("autoapi_ignore", [], "html")
     app.add_config_value("autoapi_options", _DEFAULT_OPTIONS, "html")
@@ -295,7 +270,6 @@ def setup(app):
     app.add_config_value("autoapi_python_class_content", "class", "html")
     app.add_config_value("autoapi_generate_api_docs", True, "html")
     app.add_config_value("autoapi_prepare_jinja_env", None, "html")
-    app.add_config_value("autoapi_add_objects_to_toctree", True, "html")
     app.add_autodocumenter(documenters.AutoapiFunctionDocumenter)
     app.add_autodocumenter(documenters.AutoapiPropertyDocumenter)
     app.add_autodocumenter(documenters.AutoapiDecoratorDocumenter)
