@@ -12,9 +12,12 @@ from example2 import B
 T = TypeVar("T")
 U = TypeVar("U")
 
-software = "sphinx"
+software = "sphin'x"
+more_software = 'sphinx"autoapi'
+interesting_string = "interesting\"fun'\\'string"
+
+code_snippet = """The following is some code:
 
-code_snippet = """
 # -*- coding: utf-8 -*-
 from __future__ import absolute_import, division, print_function, unicode_literals
 # from future.builtins.disabled import *
